# name, ver, rel are passed in from Makefile so we only have to set them one place
%define name lsb-test-desktop-t2c
%define ver 4.1.2
%define rel 2

# LSB Compliant packages require the following in ~/.rpmmacros
#%_binary_payload   w9.gzdio

Summary: LSB Desktop-T2C Test Suite
Vendor: ISPRAS
Name: %{name}
Version: %{ver}
Release: %{rel}
Source: %{name}-%{version}.src.tgz
License: GPL
URL: http://www.linux-foundation.org/en/Downloads
Group: Development/Tools
Buildroot: %{_builddir}/%{name}-root
AutoReqProv: no
Requires: lsb-tet3-lite >= 3.7, lsb-xvfb >= 1.2
BuildRequires: lsb-tet3-lite-devel, lsb-build-desktop

%description
The set of the LSB desktop test suites created using the T2C 
("Template-to-C") framework.

%prep
if [ ! -x /opt/lsb/bin/lsbcc ] ; then
    printf "lsbc++ not found although it is required to build the tests\n"
    exit 1
fi

%setup -q

%build
export LSBCC_BESTEFFORT=1
# build T2C framework components first
chmod -R +rx .
CUR_DIR=`pwd`
export T2C_ROOT="${CUR_DIR}/t2c_framework" 
t2c_framework/t2c/build.sh > build.log
cd desktop-t2c 
./build_all.sh 

%install

#install the test suites
T2C_ROOT=${RPM_BUILD_ROOT}/opt/lsb/test/desktop-t2c
rm -rf ${T2C_ROOT}
rm -rf ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
mkdir -p ${T2C_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}

cd desktop-t2c
for TEST_SUITE in "*-t2c"
do 
    cp -r ${TEST_SUITE} ${T2C_ROOT}
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/src ${T2C_ROOT}/${TEST_SUITE}/gen_tests ${T2C_ROOT}/${TEST_SUITE}/clean ${T2C_ROOT}/${TEST_SUITE}/*.cfg
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/testdata/testdata_src
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/Makefile ${T2C_ROOT}/${TEST_SUITE}/tests/*.mk
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/Makefile
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/*.c
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/include
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/doc
done
cd ..

install -d ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp desktop-t2c/README  ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp desktop-t2c/LICENSE ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp desktop-t2c/run_tests.sh desktop-t2c/pre-run.sh desktop-t2c/tet_code desktop-t2c/tet_scen desktop-t2c/tetexec.cfg ${T2C_ROOT}
cp -r desktop-t2c/locale ${T2C_ROOT}
cp -r desktop-t2c/mime-types ${T2C_ROOT}

%files
%defattr(777,tester,tester)
/opt/lsb/test/desktop-t2c
%dir /opt/lsb/doc/%{name}
/opt/lsb/doc/%{name}/*

%pre
PATH=/usr/sbin:$PATH

# Create 'tester' group 
# echo
# echo "Attempting to create group 'tester'"
groupadd tester >/dev/null 2>&1 || true

# if [ $? = 0 ]; then
#    echo "If you later want to delete this group, run the following command (as root):"
#    echo "    groupdel tester"
# fi

# Create a new user ('tester') if it doesn't exist.
#echo
#echo "Checking if there is a user named 'tester' on this system..."
id tester >/dev/null 2>&1

if [ $? -ne 0 ]; then 
#    echo "User 'tester' does not exist. Attempting to create it...".
    useradd -d /home/tester -s /bin/sh -c "Desktop-T2C tester login" tester -m -g tester >/dev/null 2>&1
    
    if [ $? = 0 ]; then
#        echo "User 'tester' was created successfully."
#        echo "If you later want to delete this user account, run the following command (as root):"
#        echo "    userdel -rf tester"
#        echo "Here 'userdel' is assumed to be somewhere in your path"
        echo
    else
        echo "Failed to add user 'tester'."
        echo "To be able to run the tests you should add this user manually."
        exit 1
    fi
fi

# usermod -G tester tester >/dev/null 2>&1 || true
# End of the preinstall script.

%post
RESULT=0

#install a custom locale
# echo
# echo -n "Installing \"en_POSIX_test_dec\" locale. You may need root privileges to do this."
# echo
localedef -c -f UTF-8 -i /opt/lsb/test/desktop-t2c/locale/POSIX_test_dec.ldf en_POSIX_test_dec > /dev/null 2>&1

if [ $? -gt 1 ] ; then
    RESULT=1
    echo -n "Unable to install \"en_POSIX_test_dec\" locale. "
    echo "localedef exit code is $?."
    echo "Please try to install it manually after the installation is complete."
    echo "To do this, run the following command (as root):"
    echo "localedef -c -f UTF-8 -i /opt/lsb/test/desktop-t2c/locale/POSIX_test_dec.ldf en_POSIX_test_dec"
    echo "localedef may issue warnings about missing definitions for some categories."
    echo -n "Check that \"en_POSIX_test_dec\" locale is now installed by typing "
    echo
    echo "locale -a | grep en_POSIX_test_dec"
    echo "The output should not be empty. If it is, some error has occured."
fi

#install custom image loader (for gdk-pixbuf tests)
# echo
# echo "Installing custom image loader. You may need root privileges to do this."

# restore the default list of loaders    
/opt/lsb/test/desktop-t2c/gdk-pixbuf-t2c/testdata/ModuleInterface_external/install_loader.sh -u > /dev/null 2>&1
    
# install custom loader
/opt/lsb/test/desktop-t2c/gdk-pixbuf-t2c/testdata/ModuleInterface_external/install_loader.sh

if [ $? -ne 0 ] ; then
    RESULT=1
    echo -n "Unable to install custom image loader. "
    echo "Please try to install it manually after package installation finishes."
    echo "Make sure that the program gdk-pixbuf-query-loaders or gdk-pixbuf-query-loaders-64 is in some directory specified in PATH"
    echo "To install the loader, run the following command (as root):"
    echo "/opt/lsb/test/desktop-t2c/gdk-pixbuf-t2c/testdata/ModuleInterface_external/install_loader.sh"
fi

if ! which lsb_release >/dev/null 2>&1; then
    echo
    echo "Warning: Couldn't find the required tool: lsb_release."
    echo "lsb_release should always be present in an LSB compliant distro."
    echo "You could install lsb_release and other LSB components using"
    echo "the tools provided by your distro."
    echo
    RESULT=1
fi

if lsb_release 2>&1 | grep "No LSB modules" >/dev/null 2>&1; then
    echo
    echo "Warning: No LSB modules are available."
    echo "You could install LSB modules using the tools provided by"
    echo "your distro."
    echo
    RESULT=1
fi

# put out a message
# echo "LSB Desktop-T2C Test Suite has been installed to"
# echo "/opt/lsb/test/desktop-t2c."
# if [ $RESULT -ne 0 ]; then
#    echo
#    echo "There were warnings."
# fi
# End of the postinstall script.

%preun
if [ "$1" = "0" -o "$1" = "remove" ] ; then 
    # remove
    rm -rf /opt/lsb/test/desktop-t2c/results
    rm -rf /opt/lsb/test/desktop-t2c/tet_tmp_dir
    rm -rf /opt/lsb/test/desktop-t2c/freetype-t2c/testdata
    rm -rf /opt/lsb/test/desktop-t2c/gdk-pixbuf-t2c/testdata/Scaling

    # uninstall custom locale (the commands below may do nothing on some systems)
    localedef --delete-from-archive en_POSIX_test_dec > /dev/null 2>&1
    localedef --delete-from-archive en_POSIX_test_dec.utf8 > /dev/null 2>&1

    # uninstall pixbuf loader
#    echo "Uninstalling custom image loader..."
    /opt/lsb/test/desktop-t2c/gdk-pixbuf-t2c/testdata/ModuleInterface_external/install_loader.sh -u > /dev/null 2>&1
    if [ $? -ne 0 ]; then
        echo "The custom gdk-pixbuf image loader has not been uninstalled."
#    else
#        echo "The loader has been successfully uninstalled."
    fi
fi
# End of the preuninstall script.

%clean
if [ ! -z "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then
    rm -rf ${RPM_BUILD_ROOT}
fi
